Eliminate globals.
[open-adventure.git] / init.c
diff --git a/init.c b/init.c
index 87e8da2218c0489bcab1509338a316d79b7d8d63..3d967ef222bf769d89744881cea3726729cf70f4 100644 (file)
--- a/init.c
+++ b/init.c
@@ -215,14 +215,13 @@ L1106:    /*etc*/ ;
        if(PLAC[K] != 0 && FIXD[K] <= 0)DROP(K,PLAC[K]);
        } /* end loop */
 
/*  Treasures, as noted earlier, are objects 50 through MAXTRS (CURRENTLY 79).
  *  Their props are initially -1, and are set to 0 the first time they are
  *  described.  game.tally keeps track of how many are not yet found, so we know
  *  when to close the cave. */
 
-       MAXTRS=79;
        game.tally=0;
-       for (I=50; I<=MAXTRS; I++) {
+       for (I=MINTRS; I<=MAXTRS; I++) {
        if(PTEXT[I] != 0)game.prop[I]= -1;
        game.tally=game.tally-game.prop[I];
        } /* end loop */
@@ -341,7 +340,6 @@ L1106:      /*etc*/ ;
        game.dloc[4]=44;
        game.dloc[5]=64;
        game.dloc[6]=game.chloc;
-       DALTLC=18;
 
 /*  Other random flags and counters, as follows:
  *     game.abbnum     How often we should print non-abbreviated descriptions
@@ -353,11 +351,11 @@ L1106:    /*etc*/ ;
  *     game.dkill      # of dwarves killed (unused in scoring, needed for msg)
  *     game.foobar     Current progress in saying "FEE FIE FOE FOO".
  *     game.holdng     Number of objects being carried
- *     IGO     How many times he's said "go XXX" instead of "XXX"
+ *     igo             How many times he's said "go XXX" instead of "XXX"
  *     game.iwest      How many times he's said "west" instead of "w"
  *     game.knfloc     0 if no knife here, loc if knife here, -1 after caveat
  *     game.limit      Lifetime of lamp (not set here)
- *     MAXDIE  Number of reincarnation messages available (up to 5)
+ *     MAXDIE          Number of reincarnation messages available (up to 5)
  *     game.numdie     Number of times killed so far
  *     game.thresh     Next #turns threshhold (-1 if none)
  *     game.trndex     Index in TRNVAL of next threshhold (section 14 of database)
@@ -371,7 +369,6 @@ L1106:      /*etc*/ ;
        if(TRNVLS > 0)game.thresh=MOD(TRNVAL[1],100000)+1;
        game.trnluz=0;
        game.lmwarn=false;
-       IGO=0;
        game.iwest=0;
        game.knfloc=0;
        game.detail=0;
@@ -215,14 +215,13 @@ L1106:    /*etc*/ ;
        } /* end loop */
 
-/*  Treasures, as noted earlier, are objects 50 through MAXTRS (CURRENTLY 79).
+/*  Treasures, as noted earlier, are objects MINTRS through MAXTRS
  *  Their props are initially -1, and are set to 0 the first time they are
  *  described.  game.tally keeps track of how many are not yet found, so we know